Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1060)

Unified Diff: content/renderer/media/midi_message_filter.h

Issue 324143002: Decouple IPC::MessageFilter from IPC::Channel (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Landing Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/media/audio_message_filter.cc ('k') | content/renderer/media/midi_message_filter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/media/midi_message_filter.h
diff --git a/content/renderer/media/midi_message_filter.h b/content/renderer/media/midi_message_filter.h
index 017585c702251f5e06e4de42283fe5c37609420a..e8de64d7fbde5327ed268d528f9471408e852a94 100644
--- a/content/renderer/media/midi_message_filter.h
+++ b/content/renderer/media/midi_message_filter.h
@@ -50,12 +50,12 @@ class CONTENT_EXPORT MidiMessageFilter : public IPC::MessageFilter {
virtual ~MidiMessageFilter();
private:
// Sends an IPC message using |channel_|.
void Send(IPC::Message* message);
// IPC::MessageFilter override. Called on |io_message_loop|.
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
- virtual void OnFilterAdded(IPC::Channel* channel) OVERRIDE;
+ virtual void OnFilterAdded(IPC::Sender* sender) OVERRIDE;
virtual void OnFilterRemoved() OVERRIDE;
virtual void OnChannelClosing() OVERRIDE;
@@ -94,8 +94,8 @@ class CONTENT_EXPORT MidiMessageFilter : public IPC::MessageFilter {
blink::WebMIDIAccessorClient* GetClientFromId(int client_id);
- // IPC channel for Send(); must only be accessed on |io_message_loop_|.
- IPC::Channel* channel_;
+ // IPC sender for Send(); must only be accessed on |io_message_loop_|.
+ IPC::Sender* sender_;
// Message loop on which IPC calls are driven.
const scoped_refptr<base::MessageLoopProxy> io_message_loop_;
« no previous file with comments | « content/renderer/media/audio_message_filter.cc ('k') | content/renderer/media/midi_message_filter.cc » ('j') | no next file with comments »
@@ -50,12 +50,12 @@ class CONTENT_EXPORT MidiMessageFilter : public IPC::MessageFilter {
virtual ~MidiMessageFilter();
private:
- // Sends an IPC message using |channel_|.
+ // Sends an IPC message using |sender_|.
void Send(IPC::Message* message);
// IPC::MessageFilter override. Called on |io_message_loop|.

Powered by Google App Engine
This is Rietveld 408576698